@@ -57,14 +57,14 @@ def send_notifications(email, sender, email_configuration):
 
     RECIPIENT = email
     # The subject line for the email.
-    SUBJECT = email_configuration.SUBJECT
-    LOG_PATH = email_configuration.LOG_PATH
+    SUBJECT = email_configuration.get('SUBJECT')
+    LOG_PATH = email_configuration.get('LOG_PATH')
 
     # The full path to the file that will be attached to the email.
     ATTACHMENT = LOG_PATH
 
     # # The HTML body of the email.
-    BODY_HTML = email_configuration.HTML_File
+    BODY_HTML = email_configuration.get('HTML_File')
     html_message = render_to_string(BODY_HTML)
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
